@@ -16,9 +16,10 @@ from bcf import flasher
 from bcf.log import log as bcflog
 from bcf.utils import *
 import bcf.firmware.utils as futils
+from bcf import ftdi
 
 
-__version__ = '1.7.0'
+__version__ = '1.8.0'
 SDK_URL_ZIP = 'https://codeload.github.com/hardwario/bcf-sdk/zip/master'
 SDK_GIT = 'https://github.com/hardwario/bcf-sdk.git'
 VSCODE_GIT = 'https://github.com/hardwario/bcf-vscode.git'
@@ -424,6 +425,21 @@ def command_test(path, skip_url):
         futils.test_firmware_resources(meta_yaml)
 
 
+@cli.command('ftdi')
+@click.option('-d', '--device', 'sn', type=str, help='FTDI device serial number (or regex).')
+@click.option('-m', '--manufacturer', type=str, help='Update the USB manufacturer string.')
+@click.option('-p', '--product', type=str, help='Update the USB product string.')
+@click.option('-s', '--serial', type=str, help='Update the USB serial string.')
+@click.option('-r', '--reset', is_flag=True, help='Force USB device reset.')
+def command_ftdi(sn, manufacturer=None, product=None, serial=None, reset=False):
+    '''Update USB descriptors in the FTDI chip.'''
+
+    if manufacturer is not None or product is not None or serial is not None or reset:
+        ftdi.update_eeprom(sn, manufacturer, product, serial, reset)
+    else:
+        ftdi.list_devices(sn)
+
+
 def main():
     '''Application entry point.'''
     try:
